Measurement

Struct Measurement 

pub struct Measurement(/* private fields */);
An SGX enclave measurement (MRENCLAVE): a SHA-256 hash of the enclave binary, used to verify node integrity. Serialized as a 64-character hex string.

Implementations

Source

impl Measurement

pub const MOCK_ENCLAVE: Self

pub const MOCK_SIGNER: Self

pub const DEV_SIGNER: Self

The enclave signer measurement our debug enclaves are signed with. This is also the measurement of the fortanix/rust-sgx dummy key: https://github.com/fortanix/rust-sgx/blob/master/intel-sgx/enclave-runner/src/dummy.key

Running an enclave with run-sgx .. --debug will automatically sign with this key just before running.

pub const PROD_SIGNER: Self

The enclave signer measurement our production enclaves should be signed with. Inside an enclave, get the signer with signer.

pub const fn expected_signer(use_sgx: bool, is_dev: bool) -> Self

Return the expected signer measurement by DeployEnv and whether we’re in mock or sgx mode.

pub fn compute_from_sgxs(sgxs_reader: impl Read) -> Result<Self>

Compute an enclave measurement from an .sgxs file stream std::io::Read.

  • Enclave binaries are first converted to .sgxs files, which exactly mirror the memory layout of the loaded enclave binaries right before running.
  • Conveniently, the SHA-256 hash of an enclave .sgxs binary is exactly the same as the actual enclave measurement hash, since the memory layout is identical (caveat: unless we use some more sophisticated extendable enclave features).
pub const fn new(bytes: [u8; 32]) -> Self

pub fn short(&self) -> MrShort